nbdep
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

In situations where you need a “.lock” file for version control, having
a `Pipfile` is convenient.

## Install

``` sh
pip install nbdep
```

## How to use

On the command line, cd to your `nbdev` project and then call

``` sh
cd my_project

nbdep_pipfile
```

to generate the pipfile.
